.. gromacs_py documentation master file, created by
   sphinx-quickstart on Fri Jun  1 16:36:00 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.



.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: User Documentation:

   readme
   installation
   notebook/00_basic_example.ipynb
   script
   authors
   history

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Developers:

   contributing
   modules


.. include:: ../README.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
